import { Plugin, PluginServiceApi } from '@cloudbase/framework-core';
import { NextBuilder } from '@cloudbase/next-builder';
declare const DEFAULT_INPUTS: {
    runtime: string;
    entry: string;
    name: string;
    path: string;
    buildCommand: string;
    installCommand: string;
};
/**
 * 导出接口用于生成 JSON Schema 来进行智能提示
 */
export interface IFrameworkPluginNextInputs {
    /**
     * Next 配置文件所在目录，默认当前项目所在目录
     *
     * @default ./
     */
    entry?: string;
    /**
     * 访问子路径，如 `/next-ssr`
     *
     * @default /next-ssr
     */
    path?: string;
    /**
     * 服务名，如`next-ssr`
     *
     * @default next-ssr
     */
    name?: string;
    /**
     * 构建命令，如`npm run build`，没有可不传
     *
     * @default npm run build
     */
    buildCommand?: string;
    /**
     * 安装命令，如`npm install`，没有可不传
     *
     * @default npm run build
     */
    installCommand?: string;
    /**
     * 函数运行时版本
     * @default "Nodejs10.15
     */
    runtime?: 'Nodejs10.15' | 'Nodejs8.9';
    /**
     * 函数选项
     *
     * 选填，可以支持自定义更多高级设置，例如 VPC 环境变量等
     *
     * 例如
     *
     * ```json
     * {
     *   "use": "@cloudbase/framework-plugin-next",
     *   "inputs": {
     *     "path": "/next-ssr",
     *     "name": "next-ssr",
     *     "functionOptions": {
     *       "timeout": 5,
     *       "envVariables": {
     *         "TEST_ENV": 1
     *       },
     *       "vpc": {
     *         "vpcId": "xxx",
     *         "subnetId": "xxx"
     *       }
     *     }
     *   }
     * }
     * ```
     *
     * 具体配置信息请参考 [@cloudbase/framework-plugin-function](https://github.com/Tencent/cloudbase-framework/blob/master/packages/framework-plugin-function/README.md#functions) 配置
     */
    functionOptions?: any;
}
type ResolvedInputs = IFrameworkPluginNextInputs & typeof DEFAULT_INPUTS;
declare class NextPlugin extends Plugin {
    name: string;
    api: PluginServiceApi;
    inputs: IFrameworkPluginNextInputs;
    protected resolvedInputs: ResolvedInputs;
    protected buildOutput: any;
    protected builder: NextBuilder;
    protected functionPlugin: any;
    constructor(name: string, api: PluginServiceApi, inputs: IFrameworkPluginNextInputs);
    /**
     * 初始化
     */
    init(): Promise<{
        stdout: string;
        stderr: string;
    } | undefined>;
    compile(): Promise<any>;
    /**
     * 执行本地命令
     */
    run(): Promise<void>;
    /**
     * 删除资源
     */
    remove(): Promise<void>;
    /**
     * 生成代码
     */
    genCode(): Promise<void>;
    /**
     * 构建
     */
    build(): Promise<void>;
    /**
     * 部署
     */
    deploy(): Promise<void>;
}
export declare const plugin: typeof NextPlugin;
export {};
//# sourceMappingURL=index.d.ts.map