"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.plugin = void 0;
/**
 * Tencent is pleased to support the open source community by making CloudBaseFramework - 云原生一体化部署工具 available.
 *
 * Copyright (C) 2020 THL A29 Limited, a Tencent company.  All rights reserved.
 *
 * Please refer to license text included with this package for license details.
 */
const child_process_1 = require("child_process");
const util_1 = require("util");
const fs_extra_1 = __importDefault(require("fs-extra"));
const path_1 = __importDefault(require("path"));
const framework_core_1 = require("@cloudbase/framework-core");
const framework_plugin_function_1 = require("@cloudbase/framework-plugin-function");
const next_builder_1 = require("@cloudbase/next-builder");
const DEFAULT_INPUTS = {
    runtime: 'Nodejs10.15',
    entry: './',
    name: 'next-ssr',
    path: '/next-ssr',
    buildCommand: 'npm run build',
    installCommand: 'npm install',
};
class NextPlugin extends framework_core_1.Plugin {
    constructor(name, api, inputs) {
        super(name, api, inputs);
        this.name = name;
        this.api = api;
        this.inputs = inputs;
        this.resolvedInputs = resolveInputs(this.inputs, DEFAULT_INPUTS);
        this.builder = new next_builder_1.NextBuilder({
            projectPath: this.api.projectPath,
        });
    }
    /**
     * 初始化
     */
    init() {
        return __awaiter(this, void 0, void 0, function* () {
            this.api.logger.debug('NextPlugin: init', this.resolvedInputs);
            const packageJsonPath = path_1.default.resolve(this.resolvedInputs.entry, 'package.json');
            if (fs_extra_1.default.existsSync(packageJsonPath)) {
                this.api.logger.info(`package install: ${this.resolvedInputs.installCommand}`);
                return (0, util_1.promisify)(child_process_1.exec)(this.resolvedInputs.installCommand, {
                    cwd: this.resolvedInputs.entry,
                });
            }
        });
    }
    compile() {
        return __awaiter(this, void 0, void 0, function* () {
            this.api.logger.debug('NextPlugin: compile', this.resolvedInputs);
            return this.functionPlugin.compile();
        });
    }
    /**
     * 执行本地命令
     */
    run() {
        return __awaiter(this, void 0, void 0, function* () { });
    }
    /**
     * 删除资源
     */
    remove() {
        return __awaiter(this, void 0, void 0, function* () { });
    }
    /**
     * 生成代码
     */
    genCode() {
        return __awaiter(this, void 0, void 0, function* () { });
    }
    /**
     * 构建
     */
    build() {
        return __awaiter(this, void 0, void 0, function* () {
            this.api.logger.debug('NextPlugin: build', this.resolvedInputs);
            const nextConfigPath = path_1.default.resolve(this.resolvedInputs.entry, 'next.config.js');
            if (!(yield fs_extra_1.default.pathExists(nextConfigPath))) {
                this.api.logger.info(`create next.config.js and set basePath: ${this.resolvedInputs.path}`);
                yield fs_extra_1.default.writeFile(nextConfigPath, `module.exports = { basePath: '${this.resolvedInputs.path}' }`);
            }
            const { buildCommand } = this.resolvedInputs;
            if (buildCommand) {
                yield (0, util_1.promisify)(child_process_1.exec)(buildCommand, {
                    cwd: this.resolvedInputs.entry
                });
            }
            this.buildOutput = yield this.builder.build(this.resolvedInputs.entry, {
                name: this.resolvedInputs.name,
                path: this.resolvedInputs.path,
            });
            const srcFunction = this.buildOutput.functions[0];
            this.functionPlugin = new framework_plugin_function_1.plugin('function', this.api, {
                functionRootPath: srcFunction.source,
                functions: [
                    Object.assign({ name: srcFunction.name, handler: srcFunction.entry, runtime: this.resolvedInputs.runtime, installDependency: true, ignore: ['.next/cache/**'] }, (this.resolvedInputs.functionOptions || {})),
                ],
                servicePaths: {
                    [this.resolvedInputs.name]: this.resolvedInputs.path,
                },
            });
        });
    }
    /**
     * 部署
     */
    deploy() {
        return __awaiter(this, void 0, void 0, function* () {
            this.api.logger.debug('NextPlugin: deploy', this.resolvedInputs, this.buildOutput);
            yield this.functionPlugin.deploy();
            yield this.builder.clean();
            this.api.logger.info('🚀 Next 应用部署成功');
        });
    }
}
function resolveInputs(inputs, defaultInputs) {
    return Object.assign({}, defaultInputs, inputs);
}
exports.plugin = NextPlugin;
